==> labstack-java-0.6.0-sources.jar: test/Main.java <==
package test;

import com.labstack.Client;
import com.labstack.Mqtt;
import com.labstack.MqttMessageHandler;
import org.eclipse.paho.client.mqttv3.IMqttDeliveryToken;
import org.eclipse.paho.client.mqttv3.MqttCallback;
import org.eclipse.paho.client.mqttv3.MqttMessage;

public class Main {
    public static void main(String[] args) throws Exception {
        Client client = new Client("ie8t5fgcb6s2vaxgg02y", "VouXFKK2A1TkuMUVz3wV2zvmapIdRuFM");
        Mqtt mqtt = client.Mqtt();
        mqtt.onMessage(new MqttMessageHandler() {
            @Override
            public void handle(String topic, byte[] message) {
                System.out.println(topic);
                System.out.println(new String(message));
            }
        });
        mqtt.subscribe("tracker");
//        Email email = client.Email();
//        EmailMessage message = new EmailMessage("jack@labstack.com", "LabStack", "Hello");
//        message.setBody("Hello");
//        message.addAttachment("/tmp/walle.png");
//        message = email.send(message);
//        Store store = client.Store();
//        Document document = store.insert("users", new Document()
//                .add("name", "Jack")
//                .add("location", "Disney"));
//        StoreSearchResponse response = store.search("users", new SearchParameters()
//                .setQueryString("location:Disney"));
//        System.out.println(response.getTotal());
//        System.out.println(response.getTotal());
//        StoreSearchResponse response = store.query("key='user'", 0, 5);
//        System.out.println(response.getTotal());
//        Log log = client.Log();
//        log.setLevel(Level.DEBUG);
//        log.getFields().add("app_id", "id").add("app_name", "name");
//        log.setBatchSize(20);
//        log.setDispatchInterval(5);
//        log.debug(new Fields().add("message", "debug message"));
//        log.debug("debug message");
//        log.info("%s message", "info");
//        log.warn("warn message");
//        log.error("error message");
//        log.fatal("fatal message");
    }
}

==> labstack-java-0.6.1-sources.jar: test/Main.java <==
package test;

import com.labstack.Client;
import com.labstack.Mqtt;
import com.labstack.MqttMessageHandler;
import org.eclipse.paho.client.mqttv3.IMqttDeliveryToken;
import org.eclipse.paho.client.mqttv3.MqttCallback;
import org.eclipse.paho.client.mqttv3.MqttMessage;

public class Main {
    public static void main(String[] args) throws Exception {
        Client client = new Client("ie8t5fgcb6s2vaxgg02y", "VouXFKK2A1TkuMUVz3wV2zvmapIdRuFM");
        Mqtt mqtt = client.Mqtt("xxx");
        mqtt.onMessage(new MqttMessageHandler() {
            @Override
            public void handle(String topic, byte[] message) {
                System.out.println(topic);
                System.out.println(new String(message));
            }
        });
        mqtt.subscribe("tracker");
//        Email email = client.Email();
//        EmailMessage message = new EmailMessage("jack@labstack.com", "LabStack", "Hello");
//        message.setBody("Hello");
//        message.addAttachment("/tmp/walle.png");
//        message = email.send(message);
//        Store store = client.Store();
//        Document document = store.insert("users", new Document()
//                .add("name", "Jack")
//                .add("location", "Disney"));
//        StoreSearchResponse response = store.search("users", new SearchParameters()
//                .setQueryString("location:Disney"));
//        System.out.println(response.getTotal());
//        System.out.println(response.getTotal());
//        StoreSearchResponse response = store.query("key='user'", 0, 5);
//        System.out.println(response.getTotal());
//        Log log = client.Log();
//        log.setLevel(Level.DEBUG);
//        log.getFields().add("app_id", "id").add("app_name", "name");
//        log.setBatchSize(20);
//        log.setDispatchInterval(5);
//        log.debug(new Fields().add("message", "debug message"));
//        log.debug("debug message");
//        log.info("%s message", "info");
//        log.warn("warn message");
//        log.error("error message");
//        log.fatal("fatal message");
    }
}
